==> google-cloud-sdk-265.0.0.tgz: google-cloud-sdk/lib/surface/ai_platform/models/describe.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""ai-platform models describe command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.ml_engine import models
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.ml_engine import flags


_COLLECTION = 'ml.models'


def _AddDescribeArgs(parser):
  flags.GetModelName().AddToParser(parser)


# TODO(b/62998601): don't repeat the first sentence due. Also if b/62998171 is
# resolved this should be obsolete.
class Describe(base.DescribeCommand):
  """Describe an existing AI Platform model.

  Describe an existing AI Platform model.

  If you would like to see all versions of a model, use
  `gcloud ai-platform versions list`.
  """

  @staticmethod
  def Args(parser):
    _AddDescribeArgs(parser)

  def Run(self, args):
    return models.ModelsClient().Get(args.model)

==> google-cloud-sdk-290.0.1.tgz: google-cloud-sdk/lib/surface/ai_platform/models/describe.py <==
# -*- coding: utf-8 -*- #
# Copyright 2019 Google LLC. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""ai-platform models describe command."""

from __future__ import absolute_import
from __future__ import division
from __future__ import unicode_literals

from googlecloudsdk.api_lib.ml_engine import models
from googlecloudsdk.calliope import base
from googlecloudsdk.command_lib.ml_engine import endpoint_util
from googlecloudsdk.command_lib.ml_engine import flags


_COLLECTION = 'ml.models'


def _AddDescribeArgs(parser, hide_region_flag=True):
  flags.GetModelName().AddToParser(parser)
  flags.GetRegionArg(hidden=hide_region_flag).AddToParser(parser)


def _Run(args):
  with endpoint_util.MlEndpointOverrides(region=args.region):
    return models.ModelsClient().Get(args.model)


# TODO(b/62998601): don't repeat the first sentence due. Also if b/62998171 is
# resolved this should be obsolete.
@base.ReleaseTracks(base.ReleaseTrack.GA)
class Describe(base.DescribeCommand):
  """Describe an existing AI Platform model.

  Describe an existing AI Platform model.

  If you would like to see all versions of a model, use
  `gcloud ai-platform versions list`.
  """

  @staticmethod
  def Args(parser):
    _AddDescribeArgs(parser)

  def Run(self, args):
    return _Run(args)


@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.ALPHA)
class DescribeBeta(base.DescribeCommand):
  """Describe an existing AI Platform model.

  Describe an existing AI Platform model.

  If you would like to see all versions of a model, use
  `gcloud ai-platform versions list`.
  """

  @staticmethod
  def Args(parser):
    _AddDescribeArgs(parser, hide_region_flag=False)

  def Run(self, args):
    return _Run(args)
